@@ -2,32 +2,27 @@
 #'
 #' This function computes lagged values of variables by a specified number of
 #' observations. By default, the function returns lag-1 values of the vector,
-#' matrix, or data frame specified in the first argument.
+#' or data frame specified in the first argument.
 #'
-#' @param ...     a vector for computing a lagged values for a variable, matrix
-#'                or data frame for computing lagged values for more than one
-#'                variable. Note that the subject ID variable (\code{id}),
-#'                observation number variable (\code{obs}), day number variable
-#'                (\code{day}), and the date and time variable (\code{time}) are
-#'                excluded from \code{...} when specifying the argument the
-#'                using the names of the variables. Alternatively, an expression
-#'                indicating the variable names in \code{data}. Note that the
-#'                operators \code{.}, \code{+}, \code{-}, \code{~}, \code{:},
-#'                \code{::}, and \code{!} can also be used to select variables,
-#'                see 'Details' in the \code{\link{df.subset}} function.
-#' @param data    a data frame when specifying one or more variables in the
-#'                argument \code{...}. Note that the argument is \code{NULL}
-#'                when specifying a vector, matrix, or data frame for the argument
-#'                \code{...}.
+#' @param data    a numeric vector for computing a lagged values for a variable or data
+#'                frame for computing lagged values for more than one variable.
+#'                Note that the subject ID variable (\code{id}), observation number
+#'                variable (\code{obs}), day number variable (\code{day}), and
+#'                the date and time variable (\code{time}) are excluded from
+#'                \code{data} when specifying theses arguments.
+#' @param ...     an expression indicating the variable names in \code{data}.
+#'                Note that the operators \code{.}, \code{+}, \code{-}, \code{~},
+#'                \code{:}, \code{::}, and \code{!} can also be used to select
+#'                variables, see 'Details' in the \code{\link{df.subset}} function.
 #' @param id      either a character string indicating the variable name of the
-#'                subject ID variable in '...' or a vector representing the
+#'                subject ID variable in 'data' or a vector representing the
 #'                subject IDs, see 'Details'.
 #' @param obs     either a character string indicating the variable name of the
-#'                observation number variable in '...' or a vector representing
+#'                observation number variable in 'data' or a vector representing
 #'                the observations. Note that duplicated values within the same
 #'                subject ID are not allowed, see 'Details'.
 #' @param day     either a character string indicating the variable name of the
-#'                day number variable in '...' or a vector representing the days,
+#'                day number variable in 'data' or a vector representing the days,
 #'                see 'Details'.
 #' @param lag     a numeric value specifying the lag, e.g. \code{lag = 1} (default)
 #'                returns lag-1 values.
@@ -45,30 +40,29 @@
 #'                with the ending \code{".lag"} resulting in e.g. \code{"x1.lag"}
 #'                and \code{"x2.lag"} when specifying two variables. Variable
 #'                names can also be specified using a character vector matching
-#'                the number of variables specified in \code{...}, e.g.
-#'                \code{name = c("lag.x1", "lag.x2")}).
+#'                the number of variables, e.g. \code{name = c("lag.x1", "lag.x2")}).
 #' @param name.td a character string or character vector indicating the names of
 #'                the time difference variables when specifying a date and time
 #'                variables for the argument \code{time}. By default, time
 #'                difference variables are named with the ending \code{".td"}
-#'                resulting in e.g. \code{"x1.td"} and \code{"x2.td"} when
+#'                resulting in e.g., \code{"x1.td"} and \code{"x2.td"} when
 #'                specifying two variables. Variable names can also be specified
-#'                using a character vector matching the number of variables
-#'                specified in \code{...}, e.g. \code{name = c("td.x1", "td.x2")}).
+#'                using a character vector matching the number of variables, e.g.,
+#'                \code{name = c("td.x1", "td.x2")}).
 #' @param as.na   a numeric vector indicating user-defined missing values, i.e.
 #'                these values are converted to \code{NA} before conducting the
 #'                analysis. Note that \code{as.na()} function is only applied to
-#'                the argument \code{x}, but not to \code{cluster}.
+#'                the argument \code{data}, but not to \code{cluster}.
 #' @param check   logical: if \code{TRUE} (default), argument specification is
 #'                checked.
 #'
 #' @details
 #' \describe{
 #' The function is used to create lagged versions of the variable(s) specified via
-#' the \code{...} argument:
+#' the \code{data} argument:
 #' \item{\strong{Optional argument \code{id}}}{If the \code{id} argument is not specified
 #' \code{i.e., id = NULL}, all observations are assumed to come from the same
-#' subject.  If the dataset includes multiple subjects, then this variable needs
+#' subject. If the dataset includes multiple subjects, then this variable needs
 #' to be specified so that observations are not lagged across subjects}
 #' \item{\strong{Optional argument \code{obs}}}{If the \code{obs} argument is not specified
 #' \code{i.e., obs = NULL}, consecutive observations from the same subjects are
@@ -90,7 +84,7 @@
 #'
 #' @return
 #' Returns a numeric vector or data frame with the same length or same number of
-#' rows as \code{...} containing the lagged variable(s).
+#' rows as \code{data} containing the lagged variable(s).
 #'
 #' @note
 #' This function is a modified copy of the \code{lagvar()} function in the
@@ -112,29 +106,29 @@
 #'                     neg = c(2, 3, 2, 5, 3, 4, 6, 4, 6, 4, NA, 8))
 #'
 #' # Example 1a: Lagged variable for 'pos'
-#' lagged(dat$pos, id = dat$subject, day = dat$day)
+#' lagged(dat, pos, id = "subject", day = "day")
 #'
-#' # Example 1b: Alternative specification
+#' # Alternative specification without using the '...' argument
 #' lagged(dat[, c("pos", "subject", "day")], id = "subject", day = "day")
 #'
-#' # Example 1c: Alternative specification using the 'data' argument
-#' lagged(pos, data = dat, id = "subject", day = "day")
+#' # Alternative specification using the 'data' argument
+#' lagged(dat$pos, id = dat$subject, day = dat$day)
 #'
-#' # Example 2a: Lagged variable for 'pos' and 'neg'
+#' # Example 2: Lagged variable for 'pos' and 'neg'
+#' lagged(dat, pos, neg, id = "subject", day = "day")
+#'
+#' # Alternative specification
 #' lagged(dat[, c("pos", "neg")], id = dat$subject, day = dat$day)
 #'
-#' # Example 2b: Alternative specification using the 'data' argument
-#' lagged(pos, neg, data = dat, id = "subject", day = "day")
-#'
 #' # Example 3: Lag-2 variables for 'pos' and 'neg'
-#' lagged(pos, neg, data = dat, id = "subject", day = "day", lag = 2)
+#' lagged(dat, pos, neg, id = "subject", day = "day", lag = 2)
 #'
 #' # Example 4: Lagged variable and time difference variable
-#' lagged(pos, neg, data = dat, id = "subject", day = "day", time = "time")
+#' lagged(dat, pos, neg, id = "subject", day = "day", time = "time")
 #'
 #' # Example 5: Lagged variables and time difference variables,
 #' # name variables
-#' lagged(pos, neg, data = dat, id = "subject", day = "day", time = "time",
+#' lagged(dat, pos, neg, id = "subject", day = "day", time = "time",
 #'        name = c("p.lag1", "n.lag1"), name.td = c("p.diff", "n.diff"))
 #'
 #' # Example 6: NA observations excluded from the data frame
@@ -143,11 +137,11 @@
 #' # Number of observation not taken into account, i.e.,
 #' # - observation 4 used as lagged value for observation 6 for subject 1
 #' # - observation 1 used as lagged value for observation 3 for subject 2
-#' lagged(pos, data = dat.excl, id = "subject", day = "day")
+#' lagged(dat.excl,  pos, id = "subject", day = "day")
 #'
 #' # Number of observation taken into account by specifying the 'ob' argument
-#' lagged(pos, data = dat.excl, id = "subject", day = "day", obs = "obs")
-lagged <- function(..., data = NULL, id = NULL, obs = NULL, day = NULL, lag = 1, time = NULL,
+#' lagged(dat.excl, pos, id = "subject", day = "day", obs = "obs")
+lagged <- function(data, ..., id = NULL, obs = NULL, day = NULL, lag = 1, time = NULL,
                    units = c("secs", "mins", "hours", "days", "weeks"),
                    append = TRUE, name = ".lag", name.td = ".td", as.na = NULL, check = TRUE) {
 
@@ -155,11 +149,11 @@ lagged <- function(..., data = NULL, id = NULL, obs = NULL, day = NULL, lag = 1,
   #
   # Initial Check --------------------------------------------------------------
 
-  # Check if input '...' is missing
-  if (isTRUE(missing(...))) { stop("Please specify the argument '...'.", call. = FALSE) }
+  # Check if input 'data' is missing
+  if (isTRUE(missing(data))) { stop("Please specify a numeric vector or data frame for the argument 'data'", call. = FALSE) }
 
-  # Check if input '...' is NULL
-  if (isTRUE(is.null(substitute(...)))) { stop("Input specified for the argument '...' is NULL.", call. = FALSE) }
+  # Check if input 'data' is NULL
+  if (isTRUE(is.null(data))) { stop("Input specified for the argument 'data' is NULL.", call. = FALSE) }
 
   #_____________________________________________________________________________
   #
@@ -168,16 +162,13 @@ lagged <- function(..., data = NULL, id = NULL, obs = NULL, day = NULL, lag = 1,
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Data using the argument 'data' ####
 
-  if (isTRUE(!is.null(data))) {
-
-    # Convert tibble into data frame
-    if (isTRUE("tbl" %in% substr(class(data), 1L, 3L))) { data <- as.data.frame(data) }
+  if (isTRUE(!missing(...))) {
 
     # Variable names
-    var.names <- .var.names(..., data = data, id = id, obs = obs, day = day, time = time, check.chr = "vector, matrix, or data frame")
+    var.names <- .var.names(..., data = data, id = id, obs = obs, day = day, time = time)
 
-    # Extract variables
-    x <- data[, var.names]
+    # Extract data and convert tibble into data frame or vector
+    x <- data[, var.names] |> (\(y) if (isTRUE("tbl" %in% substr(class(y), 1L, 3L))) { if (isTRUE(ncol(as.data.frame(y)) == 1L)) { unname(unlist(y)) } else { as.data.frame(y) } } else { y })()
 
     # Subject ID variable
     if (isTRUE(!is.null(id))) { id <- data[, id] }
@@ -196,16 +187,13 @@ lagged <- function(..., data = NULL, id = NULL, obs = NULL, day = NULL, lag = 1,
 
   } else {
 
-    # Extract data
-    x <- eval(..., enclos = parent.frame())
+    # Convert 'data' as tibble into data frame
+    x <- data |> (\(y) if (isTRUE("tbl" %in% substr(class(y), 1L, 3L))) { if (isTRUE(ncol(as.data.frame(y)) == 1L)) { unname(unlist(y)) } else { as.data.frame(y) } } else { y })()
 
-    # Convert tibble into data frame
-    if (isTRUE("tbl" %in% substr(class(x), 1L, 3L))) { if (isTRUE(ncol(as.data.frame(x)) == 1L)) { x <- unlist(x) } else { x <- as.data.frame(x) } }
-
-    # Data, ID and time variables
+    # Data and cluster
     var.group <- .var.group(data = x, id = id, obs = obs, day = day, time = time)
 
-    # Data
+    # Data, id, obs, day, and time variable
     if (isTRUE(!is.null(var.group$data)))  { x <- var.group$data }
 
     # Subject ID variable
@@ -222,6 +210,12 @@ lagged <- function(..., data = NULL, id = NULL, obs = NULL, day = NULL, lag = 1,
 
   }
 
+  # Convert 'id', 'obs', 'day' and 'time' as tibble into a vector
+  if (!is.null(id) && isTRUE("tbl" %in% substr(class(id), 1L, 3L))) { id <- unname(unlist(id)) }
+  if (!is.null(obs) && isTRUE("tbl" %in% substr(class(obs), 1L, 3L))) { obs <- unname(unlist(obs)) }
+  if (!is.null(day) && isTRUE("tbl" %in% substr(class(day), 1L, 3L))) { day <- unname(unlist(day)) }
+  if (!is.null(time) && isTRUE("tbl" %in% substr(class(time), 1L, 3L))) { time <- as.vector(time)[[1L]] }
+
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Convert user-missing values into NA ####
 
@@ -241,9 +235,7 @@ lagged <- function(..., data = NULL, id = NULL, obs = NULL, day = NULL, lag = 1,
   # Input Check ----------------------------------------------------------------
 
   # Check inputs
-  .check.input(logical = "append",
-               numeric = list(lag = 1L),
-               s.character = list(units = c("secs", "mins", "hours", "days", "weeks")), envir = environment(), input.check = check)
+  .check.input(logical = "append", numeric = list(lag = 1L), s.character = list(units = c("secs", "mins", "hours", "days", "weeks")), envir = environment(), input.check = check)
 
   if (isTRUE(check)) {
 
@@ -398,7 +390,7 @@ lagged <- function(..., data = NULL, id = NULL, obs = NULL, day = NULL, lag = 1,
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Append ####
 
-  if (isTRUE(!is.null(data) && append)) {
+  if (isTRUE(!missing(...) && append)) {
 
     if (isTRUE(is.null(dim(x)))) {
 
